#
# spec file for package thunar-vcs-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thunar-vcs-plugin
Version:        0.3.0
Release:        bp160.1.6
Summary:        Thunar Plugin Providing VCS Integration
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://goodies.xfce.org/projects/thunar-plugins/thunar-vcs-plugin
Source0:        http://archive.xfce.org/src/thunar-plugins/thunar-vcs-plugin/0.3/%{name}-%{version}.tar.bz2
Source99:       %{name}.changes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  subversion-devel
BuildRequires:  pkgconfig(apr-1) >= 0.9.7
BuildRequires:  pkgconfig(exo-2) >= 0.11.4
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.18.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.18.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(thunarx-3) >= 1.2.0
Requires:       thunar >= 1.7.0
Recommends:     %{name}-lang = %{version}
Provides:       thunar-plugin-vcs = %{version}
Obsoletes:      thunar-plugin-vcs < %{version}

%description
The Thunar VCS Plugin provides integration with Subversion and GIT VCS and
makes VCS actions available through the context menu.

%lang_package

%prep
%autosetup

%build
export SOURCE_DATE_EPOCH=$(date +%s -r %{S:99})
%configure \
            --enable-git \
            --disable-static

%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/thunarx-3/thunar-vcs-plugin.la

%find_lang %{name} %{?no_lang_C}

%files
%doc README.md ChangeLog NEWS AUTHORS
%license COPYING
%{_libexecdir}/tvp-git-helper
%{_libexecdir}/tvp-svn-helper
%{_libdir}/thunarx-3/%{name}.so
%{_datadir}/icons/hicolor/*/apps/git.png
%{_datadir}/icons/hicolor/*/apps/subversion.png

%files lang -f %{name}.lang

%changelog
* Sat Jan 11 2025 Maurizio Galli <maurizio.galli@suse.com>
- Package renamed from thunar-plugin-vcs to thunar-vcs-plugin to
  follow upstream name convention
- Update to 0.3.0:
  * Fix string array leak in tvp-git-helper main
  * Fix GOptionContext leak in tvp-git-helper main
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Add missing check for bind_textdomain_codeset
  * tsh-log-dialog: fix -Wcast-function-type
  * svn-revert: Avoid svn-1.11 deprecated function
  * svn-diff: Avoid svn 1.11 deprecated function
  * svn-diff: Avoid svn 1.8 deprecated function
  * svn-blame: Avoid svn 1.12 deprecated function
  * svn: Add a tsh_blame_baton wrapper
  * I18n: Update po/LINGUAS list
  * build: Require apr-util-1
  * Fix autotools warning, get rid of intltool
  * Fix compilation warnings
  * autoconf: AM_CONFIG_HEADER -> AC_CONFIG_HEADERS
  * Create README.md. Update configure.ac.in
  * Translation Updates
* Fri Mar 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Undo the last change. Issue has to be resolved in libserf.
  See boo#1221211 and boo#1222938
* Sun Mar 10 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update build requirements; i.e. require openssl < 3 for Leap 15.6
  (see boo#1221211).
* Mon Aug  6 2018 seife+obs@b1-systems.com
- update to 0.2.0
  - Fix context menu strings.
  - Add description to commands, shown on Thunar's status bar.
  - Translation updates.
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to 0.1.90
  - GTK3 Port
  - Thunarx-3 Port (Thunar >=1.7.0 required)
  - Remove spaces before ellipsis (bxo#14264)
  - Translation updates
* Tue Oct  3 2017 jengelh@inai.de
- Remove redundant %%clean section.
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to 0.1.5:
  * Tons of svn improvements/fixes, courtesy of Stefan Sperling
  * Fixed MACRO naming in makefiles. bxo#7850
  * Fixed invalid usage of g_quark_from_static_string. bxo#6322
- improve buildtime avoidance by using SOURCE_DATE_EPOCH variable
* Tue Mar 27 2012 gber@opensuse.org
- added source URL
* Thu Mar 22 2012 gber@opensuse.org
- enabled subversion support
- updated build dependencies
- corrected URL
* Wed Mar 14 2012 gber@opensuse.org
- recommend -lang subpackage
* Wed Mar 23 2011 gber@opensuse.org
- new package
